@@ -9,11 +9,59 @@ Mojolicious::Plugin::AssetPack::Preprocessors - Holds preprocessors for the asse
 L<Mojolicious::Plugin::AssetPack::Preprocessors> is used to hold a list of
 preprocessors for a given file type.
 
-=head2 SEE ALSO
+=head2 Bundled preprocessors
 
-L<Mojolicious::Plugin::AssetPack::Preprocessor>,
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Sass> and
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Scss>.
+L<Mojolicious::Plugin::AssetPack> will load the preprocessors in the list
+below, when you try to handle a given file.
+
+NOTE! Some of the preprocessors require optional dependencies to function
+properly.
+
+=over 4
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::CoffeeScript>
+
+Handle C<.coffee> files.
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::Css>
+
+Handle C<.css> files.
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::JavaScript>
+
+Handle C<.js> files.
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::Jsx>
+
+Handle C<.jsx> files.
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::Less>
+
+Handle C<.less> files.
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::Sass>
+
+Handle C<.sass> files.
+
+=item * L<Mojolicious::Plugin::AssetPack::Preprocessor::Scss>
+
+Handle C<.scss> files.
+
+=back
+
+=head2 Custom preprocessors
+
+You can also define your own preprocessors. Example code:
+
+  package My::Preprocessor;
+  use Mojo::Base 'Mojolicious::Plugin::AssetPack::Preprocessor';
+
+  sub process {
+    my ($self, $assetpack, $text, $path) = @_;
+    $$text = "// yikes!\n" if 5 < rand 10;
+  }
+
+  app->asset->preprocessors->add(js => My::Preprocessor->new);
 
 =cut
 
@@ -24,9 +72,20 @@ use Cwd;
 use File::Basename;
 use File::Which;
 use IPC::Run3 ();
+use constant DEBUG => $ENV{MOJO_ASSETPACK_DEBUG} || 0;
 
 our $VERSION = '0.01';
 
+my %PREPROCESSORS = (
+  coffee => 'Mojolicious::Plugin::AssetPack::Preprocessor::CoffeeScript',
+  css => 'Mojolicious::Plugin::AssetPack::Preprocessor::Css',
+  js => 'Mojolicious::Plugin::AssetPack::Preprocessor::JavaScript',
+  jsx => 'Mojolicious::Plugin::AssetPack::Preprocessor::Jsx',
+  less => 'Mojolicious::Plugin::AssetPack::Preprocessor::Less',
+  sass => 'Mojolicious::Plugin::AssetPack::Preprocessor::Sass',
+  scss => 'Mojolicious::Plugin::AssetPack::Preprocessor::Scss',
+);
+
 =head1 METHODS
 
 =head2 add
@@ -42,8 +101,6 @@ Define a preprocessor which is run on a given file extension. These
 preprocessors will be chained. The callbacks will be called in the order they
 where added.
 
-The default preprocessor defined is described under L</detect>.
-
 In case of C<$object>, the object need to be able to have the C<process()>
 method.
 
@@ -77,7 +134,7 @@ actually installed.
 sub can_process {
   my ($self, $extension) = @_;
 
-  for my $p (@{ $self->subscribers($extension) }) {
+  for my $p ($self->_preprocessors($extension)) {
     return 1 if $p->can_process;
   }
 
@@ -103,7 +160,7 @@ sub checksum {
 
   eval {
     chdir dirname $filename if $filename;
-    push @checksum, $_->checksum($text, $filename) for @{ $self->subscribers($extension) };
+    push @checksum, $_->checksum($text, $filename) for $self->_preprocessors($extension);
     1;
   } or do {
     $err = $@ || "AssetPack failed with unknown error while processing $filename.\n";
@@ -116,41 +173,13 @@ sub checksum {
 
 =head2 detect
 
-Will add
-
-L<Mojolicious::Plugin::AssetPack::Preprocessor::CoffeeScript>,
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Css>,
-L<Mojolicious::Plugin::AssetPack::Preprocessor::JavaScript>,
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Jsx>,
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Less>,
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Sass> and
-L<Mojolicious::Plugin::AssetPack::Preprocessor::Scss> as preprocessors.
+DEPRECATED. Default handlers are added on the fly.
 
 =cut
 
 sub detect {
-  my $self = shift;
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::Css;
-  $self->add(css => Mojolicious::Plugin::AssetPack::Preprocessor::Css->new);
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::CoffeeScript;
-  $self->add(coffee => Mojolicious::Plugin::AssetPack::Preprocessor::CoffeeScript->new);
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::JavaScript;
-  $self->add(js => Mojolicious::Plugin::AssetPack::Preprocessor::JavaScript->new);
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::Less;
-  $self->add(less => Mojolicious::Plugin::AssetPack::Preprocessor::Less->new);
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::Jsx;
-  $self->add(jsx => Mojolicious::Plugin::AssetPack::Preprocessor::Jsx->new);
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::Sass;
-  $self->add(sass => Mojolicious::Plugin::AssetPack::Preprocessor::Sass->new);
-
-  require Mojolicious::Plugin::AssetPack::Preprocessor::Scss;
-  $self->add(scss => Mojolicious::Plugin::AssetPack::Preprocessor::Scss->new);
+  warn "DEPRECATED".
+  $_[0];
 }
 
 =head2 process
@@ -171,7 +200,7 @@ sub process {
 
   eval {
     chdir dirname $filename;
-    $_->($_, $assetpack, $text, $filename) for @{ $self->subscribers($extension) };
+    $_->($_, $assetpack, $text, $filename) for $self->_preprocessors($extension);
     1;
   } or do {
     $err = $@ || "AssetPack failed with unknown error while processing $filename.\n";
@@ -198,6 +227,21 @@ given C<$cb>.
 
 sub remove { shift->unsubscribe(@_) }
 
+sub _preprocessors {
+  my ($self, $extension) = @_;
+  my @preprocessors = @{ $self->subscribers($extension) };
+
+  return @preprocessors if @preprocessors;
+
+  if (my $class = $PREPROCESSORS{$extension}) {
+    warn "[ASSETPACK] Adding $class preprocessor.\n" if DEBUG;
+    eval "require $class;1" or die "Could not load $class: $@\n";
+    return $self->add($extension => $class->new);
+  }
+
+  return;
+}
+
 =head1 AUTHOR
 
 Jan Henning Thorsen - C<jhthorsen@cpan.org>
